==> gorilla-notes-0.5.1.jar: public/js/compiled/cljs-runtime/gorilla_notes.state.js <==
goog.provide('gorilla_notes.state');
gorilla_notes.state._STAR_state = reagent.core.atom.cljs$core$IFn$_invoke$arity$1(new cljs.core.PersistentArrayMap(null, 3, [new cljs.core.Keyword(null,"ids","ids",-998535796),cljs.core.PersistentVector.EMPTY,new cljs.core.Keyword(null,"id->content","id->content",-1932164173),cljs.core.PersistentArrayMap.EMPTY,new cljs.core.Keyword(null,"options","options",99638489),cljs.core.PersistentArrayMap.EMPTY], null));
gorilla_notes.state.reset_ids_BANG_ = (function gorilla_notes$state$reset_ids_BANG_(ids){
return cljs.core.swap_BANG_.cljs$core$IFn$_invoke$arity$4(gorilla_notes.state._STAR_state,cljs.core.assoc,new cljs.core.Keyword(null,"ids","ids",-998535796),ids);
});
gorilla_notes.state.set_uid_BANG_ = (function gorilla_notes$state$set_uid_BANG_(uid){
return cljs.core.swap_BANG_.cljs$core$IFn$_invoke$arity$4(gorilla_notes.state._STAR_state,cljs.core.assoc,new cljs.core.Keyword(null,"uid","uid",-1447769400),uid);
});
gorilla_notes.state.reset_options_BANG_ = (function gorilla_notes$state$reset_options_BANG_(options){
return cljs.core.swap_BANG_.cljs$core$IFn$_invoke$arity$4(gorilla_notes.state._STAR_state,cljs.core.assoc,new cljs.core.Keyword(null,"options","options",99638489),options);
});
gorilla_notes.state.update_content_BANG_ = (function gorilla_notes$state$update_content_BANG_(i,id,content){
return cljs.core.swap_BANG_.cljs$core$IFn$_invoke$arity$2(gorilla_notes.state._STAR_state,(function (state){
return cljs.core.assoc_in(cljs.core.assoc_in(state,new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"id->content","id->content",-1932164173),id], null),content),new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"ids","ids",-998535796),i], null),id);
}));
});
gorilla_notes.state.cleanup_content_BANG_ = (function gorilla_notes$state$cleanup_content_BANG_(){
return cljs.core.swap_BANG_.cljs$core$IFn$_invoke$arity$2(gorilla_notes.state._STAR_state,(function (state){
var obsolete_ids = cljs.core.filter.cljs$core$IFn$_invoke$arity$2(cljs.core.complement(cljs.core.set(new cljs.core.Keyword(null,"ids","ids",-998535796).cljs$core$IFn$_invoke$arity$1(state))),cljs.core.keys(new cljs.core.Keyword(null,"id->content","id->content",-1932164173).cljs$core$IFn$_invoke$arity$1(state)));
return cljs.core.update.cljs$core$IFn$_invoke$arity$3(state,new cljs.core.Keyword(null,"id->content","id->content",-1932164173),(function (p1__41595_SHARP_){
return cljs.core.apply.cljs$core$IFn$_invoke$arity$3(cljs.core.dissoc,p1__41595_SHARP_,obsolete_ids);
}));
}));
});

//# sourceMappingURL=gorilla_notes.state.js.map

==> gorilla-notes-0.5.3.jar: public/js/compiled/cljs-runtime/gorilla_notes.state.js <==
goog.provide('gorilla_notes.state');
gorilla_notes.state._STAR_state = reagent.core.atom.cljs$core$IFn$_invoke$arity$1(new cljs.core.PersistentArrayMap(null, 3, [new cljs.core.Keyword(null,"ids","ids",-998535796),cljs.core.PersistentVector.EMPTY,new cljs.core.Keyword(null,"id->content","id->content",-1932164173),cljs.core.PersistentArrayMap.EMPTY,new cljs.core.Keyword(null,"options","options",99638489),cljs.core.PersistentArrayMap.EMPTY], null));
gorilla_notes.state.reset_ids_BANG_ = (function gorilla_notes$state$reset_ids_BANG_(ids){
return cljs.core.swap_BANG_.cljs$core$IFn$_invoke$arity$4(gorilla_notes.state._STAR_state,cljs.core.assoc,new cljs.core.Keyword(null,"ids","ids",-998535796),ids);
});
gorilla_notes.state.set_uid_BANG_ = (function gorilla_notes$state$set_uid_BANG_(uid){
return cljs.core.swap_BANG_.cljs$core$IFn$_invoke$arity$4(gorilla_notes.state._STAR_state,cljs.core.assoc,new cljs.core.Keyword(null,"uid","uid",-1447769400),uid);
});
gorilla_notes.state.reset_options_BANG_ = (function gorilla_notes$state$reset_options_BANG_(options){
return cljs.core.swap_BANG_.cljs$core$IFn$_invoke$arity$4(gorilla_notes.state._STAR_state,cljs.core.assoc,new cljs.core.Keyword(null,"options","options",99638489),options);
});
gorilla_notes.state.update_content_BANG_ = (function gorilla_notes$state$update_content_BANG_(i,id,content){
return cljs.core.swap_BANG_.cljs$core$IFn$_invoke$arity$2(gorilla_notes.state._STAR_state,(function (state){
return cljs.core.assoc_in(cljs.core.assoc_in(state,new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"id->content","id->content",-1932164173),id], null),content),new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"ids","ids",-998535796),i], null),id);
}));
});
gorilla_notes.state.cleanup_content_BANG_ = (function gorilla_notes$state$cleanup_content_BANG_(){
return cljs.core.swap_BANG_.cljs$core$IFn$_invoke$arity$2(gorilla_notes.state._STAR_state,(function (state){
var obsolete_ids = cljs.core.filter.cljs$core$IFn$_invoke$arity$2(cljs.core.complement(cljs.core.set(new cljs.core.Keyword(null,"ids","ids",-998535796).cljs$core$IFn$_invoke$arity$1(state))),cljs.core.keys(new cljs.core.Keyword(null,"id->content","id->content",-1932164173).cljs$core$IFn$_invoke$arity$1(state)));
return cljs.core.update.cljs$core$IFn$_invoke$arity$3(state,new cljs.core.Keyword(null,"id->content","id->content",-1932164173),(function (p1__23162_SHARP_){
return cljs.core.apply.cljs$core$IFn$_invoke$arity$3(cljs.core.dissoc,p1__23162_SHARP_,obsolete_ids);
}));
}));
});
gorilla_notes.state.port = (function gorilla_notes$state$port(){
return new cljs.core.Keyword(null,"port","port",1534937262).cljs$core$IFn$_invoke$arity$1(new cljs.core.Keyword(null,"options","options",99638489).cljs$core$IFn$_invoke$arity$1(cljs.core.deref(gorilla_notes.state._STAR_state)));
});

//# sourceMappingURL=gorilla_notes.state.js.map
